==> haskell-uuid-1.3.15-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uuid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 uuid
version:              1.3.15
visibility:           public
id:                   uuid-1.3.15-EJcquRhFHKA2YCPQWoQVRg
key:                  uuid-1.3.15-EJcquRhFHKA2YCPQWoQVRg
license:              BSD-3-Clause
copyright:            (c) 2008-2014 Antoine Latter
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Antoine Latter
homepage:             https://github.com/haskell-hvr/uuid
synopsis:
    For creating, comparing, parsing and printing Universally Unique Identifiers

description:
    This library is useful for creating, comparing, parsing and
    printing Universally Unique Identifiers.

    See <http://en.wikipedia.org/wiki/UUID> for the general idea.

category:             Data
abi:                  e43fc35179f6ecf59968d7403733ec8c
exposed:              True
exposed-modules:
    Data.UUID Data.UUID.Util Data.UUID.V1 Data.UUID.V3 Data.UUID.V4
    Data.UUID.V5

hidden-modules:       Data.UUID.Named Data.Word.Util
import-dirs:          /usr/lib/ghc-9.0.2/site-local/uuid-1.3.15
library-dirs:         /usr/lib/ghc-9.0.2/site-local/uuid-1.3.15
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/uuid-1.3.15
hs-libraries:         HSuuid-1.3.15-EJcquRhFHKA2YCPQWoQVRg
depends:
    base-4.15.1.0 binary-0.8.8.0 bytestring-0.10.12.1
    cryptohash-md5-0.11.101.0-4p34NwPfudy44bdQXtL6Hi
    cryptohash-sha1-0.11.101.0-LlYf1Ib0evy1n2veq6j7AF
    entropy-0.4.1.7-Af27lR5RV911FT1IImZ36i
    network-info-0.2.0.10-E7GgxJGjpoB4rmOJt4Or7S
    random-1.2.1-8YD4HcLDPYgGXmQa09Ed9l text-1.2.5.0 time-1.9.3
    uuid-types-1.0.5-p6XKwEL6vRDVerfZiNWE3

haddock-interfaces:   /usr/share/doc/haskell-uuid/html/uuid.haddock
haddock-html:         /usr/share/doc/haskell-uuid/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uuid-1.3.15-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uuid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 uuid
version:              1.3.15
visibility:           public
id:                   uuid-1.3.15-uJQEvpifULCDFEyISPKJE
key:                  uuid-1.3.15-uJQEvpifULCDFEyISPKJE
license:              BSD-3-Clause
copyright:            (c) 2008-2014 Antoine Latter
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Antoine Latter
homepage:             https://github.com/haskell-hvr/uuid
synopsis:
    For creating, comparing, parsing and printing Universally Unique Identifiers

description:
    This library is useful for creating, comparing, parsing and
    printing Universally Unique Identifiers.

    See <http://en.wikipedia.org/wiki/UUID> for the general idea.

category:             Data
abi:                  6f9a450f66d6ca3a5cede3b29f0c5a7f
exposed:              True
exposed-modules:
    Data.UUID Data.UUID.Util Data.UUID.V1 Data.UUID.V3 Data.UUID.V4
    Data.UUID.V5

hidden-modules:       Data.UUID.Named Data.Word.Util
import-dirs:          /usr/lib/ghc-9.0.2/site-local/uuid-1.3.15
library-dirs:         /usr/lib/ghc-9.0.2/site-local/uuid-1.3.15
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/uuid-1.3.15
hs-libraries:         HSuuid-1.3.15-uJQEvpifULCDFEyISPKJE
depends:
    base-4.15.1.0 binary-0.8.8.0 bytestring-0.10.12.1
    cryptohash-md5-0.11.101.0-5bmNMmCAMFK6IDT5QynTDH
    cryptohash-sha1-0.11.101.0-JndEZjFr2uy345lv4zYcnh
    entropy-0.4.1.7-Af27lR5RV911FT1IImZ36i
    network-info-0.2.0.10-E7GgxJGjpoB4rmOJt4Or7S
    random-1.2.1-87zKbQkst0gDIGMfu6nhpe text-1.2.5.0 time-1.9.3
    uuid-types-1.0.5-HcVHrlJjS11BcOSmBnkO0U

haddock-interfaces:   /usr/share/doc/haskell-uuid/html/uuid.haddock
haddock-html:         /usr/share/doc/haskell-uuid/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
